pub(crate) enum ScriptEventLoopReceiver {
MainThread(Receiver<MainThreadScriptMsg>),
SharedWorker(Receiver<SharedWorkerScriptMsg>),
DedicatedWorker(Receiver<DedicatedWorkerScriptMsg>),
}Expand description
A wrapper around various types of Receivers that receive event loop messages. Used for
synchronous DOM APIs that need to abstract over multiple kinds of event loops (worker/main
thread) with different Receiver interfaces.
Variants
MainThread(Receiver<MainThreadScriptMsg>)
A receiver that receives messages to the main ScriptThread event loop.
A receiver that receives messages to shared worker event loops.
DedicatedWorker(Receiver<DedicatedWorkerScriptMsg>)
A receiver that receives messages to dedicated workers (such as a generic Web Worker) event loop.
Implementations
Sourceimpl ScriptEventLoopReceiver
impl ScriptEventLoopReceiver
pub(crate) fn recv(&self) -> Result<CommonScriptMsg, ()>